@@ -253,6 +253,31 @@ class CohortChangeRequested(OpenEdxPublicFilter):
         return data.get("current_membership"), data.get("target_cohort")
 
 
+class CohortAssignmentRequested(OpenEdxPublicFilter):
+    """
+    Custom class used to create cohort assignment filters and its custom methods.
+    """
+
+    filter_type = "org.openedx.learning.cohort.assignment.requested.v1"
+
+    class PreventCohortAssignment(OpenEdxFilterException):
+        """
+        Custom class used to stop the cohort assignment process.
+        """
+
+    @classmethod
+    def run_filter(cls, user, target_cohort):
+        """
+        Execute a filter with the signature specified.
+
+        Arguments:
+            user (User): is a Django User object to be added in the cohort.
+            target_cohort (CourseUserGroup): edxapp object representing the new user's cohort.
+        """
+        data = super().run_pipeline(user=user, target_cohort=target_cohort)
+        return data.get("user"), data.get("target_cohort")
+
+
 class CourseAboutRenderStarted(OpenEdxPublicFilter):
     """
     Custom class used to create course about render filters and its custom methods.
@@ -397,3 +422,47 @@ class DashboardRenderStarted(OpenEdxPublicFilter):
         """
         data = super().run_pipeline(context=context, template_name=template_name)
         return data.get("context"), data.get("template_name")
+
+
+class VerticalBlockChildRenderStarted(OpenEdxPublicFilter):
+    """
+    Custom class used to create vertical block children's render filters.
+    """
+
+    filter_type = "org.openedx.learning.vertical_block_child.render.started.v1"
+
+    @classmethod
+    def run_filter(cls, block, context):
+        """
+        Execute a filter with the signature specified.
+
+        Arguments:
+            block (XBlock): the XBlock that is about to be rendered into HTML
+            context (dict): rendering context values like is_mobile_app, show_title..etc
+        """
+        data = super().run_pipeline(block=block, context=context)
+        return data.get("block"), data.get("context")
+
+
+class CourseEnrollmentQuerysetRequested(OpenEdxPublicFilter):
+    """
+    Custom class used to create course enrollments queryset filters and its custom methods.
+    """
+
+    filter_type = "org.openedx.learning.course_enrollment_queryset.requested.v1"
+
+    class PreventEnrollmentQuerysetRequest(OpenEdxFilterException):
+        """
+        Custom class used to stop the course enrollment queryset request process.
+        """
+
+    @classmethod
+    def run_filter(cls, enrollments):
+        """
+        Execute a filter with the signature specified.
+
+        Arguments:
+        enrollments (QuerySet): data with all user's course enrollments
+        """
+        data = super().run_pipeline(enrollments=enrollments)
+        return data.get("enrollments")
